@@ -4,10 +4,14 @@ from requests import HTTPError, RequestException
 import logging
 import os
 import shutil
-from pycomunefirenze.working_dir import WorkingDir
 from pathlib import Path
 import psycopg2
 import sys
+from redmail import EmailSender
+try:
+    from pycomunefirenze.working_dir import WorkingDir
+except ModuleNotFoundError:
+    from working_dir import WorkingDir
 
 proxies = {
     'http': 'http://proxyhttp.comune.intranet:8080',
@@ -96,12 +100,14 @@ def __create_sql_query(table_name: str, column_names: List[str]) -> str:
         str: query
     """
     if not isinstance(table_name, str):
-        raise ValueError(f'The name of the table must be a string, and {table_name} is a {type(table_name)}')
+        raise ValueError(
+            f'The name of the table must be a string, and {table_name} is a {type(table_name)}')
     columns_declaration = "("
     values_declaration = "("
     for idx, column in enumerate(column_names):
         if not isinstance(column, str):
-            raise ValueError((f'The name of each column must be a string, and {column} is a {type(column)}'))
+            raise ValueError(
+                (f'The name of each column must be a string, and {column} is a {type(column)}'))
         columns_declaration += f"{column}"
         values_declaration += f"%s"
         if idx != len(column_names)-1:
@@ -127,7 +133,7 @@ def insert_on_db(user: str, password: str, host: str, port: str, database: str,
         rows (List[List[Any]]): lista di righe sottoforma di tuple
 
     Returns:
-        cursor: oggetto per effettuare query su db
+        boolean: controllo per verificare se la scrittura è andata a buon fine o no
     """
     # todo far scrivere la insert in automatico passando nome tabella e nome colonne
     connection = None
@@ -150,3 +156,26 @@ def insert_on_db(user: str, password: str, host: str, port: str, database: str,
         if connection is not None:
             connection.close()
     return True
+
+
+def send_email(subject: str, sender: str, receivers: List[str], text: str, **kwargs) -> Any:
+    """Manda una mail utilizzando il server mail interno 
+
+    Args:
+        subject (str): oggetto della mail
+        sender (str): mittende
+        receivers (List[str]): lista di destinatari
+        text (str): testo della mail
+        **kwargs: argomenti opzionali, vedi https://pypi.org/project/redmail/
+
+    Returns:
+        EmailMessage: [description]
+    """
+    email = EmailSender(host='mailint.comune.intranet', port=25)
+    return email.send(
+        subject=subject,
+        sender=sender,
+        receivers=receivers,
+        text=text,
+        **kwargs
+    )
